@@ -1,12 +1,10 @@
 package rules
 
 import (
-	regexp "github.com/wasilibs/go-re2"
-
 	"github.com/zricethezav/gitleaks/v8/cmd/generate/config/utils"
-	"github.com/zricethezav/gitleaks/v8/config"
-
 	"github.com/zricethezav/gitleaks/v8/cmd/generate/secrets"
+	"github.com/zricethezav/gitleaks/v8/config"
+	"github.com/zricethezav/gitleaks/v8/regexp"
 )
 
 func Dynatrace() *config.Rule {
@@ -16,7 +14,7 @@ func Dynatrace() *config.Rule {
 		Description: "Detected a Dynatrace API token, potentially risking application performance monitoring and data exposure.",
 		Regex:       regexp.MustCompile(`dt0c01\.(?i)[a-z0-9]{24}\.[a-z0-9]{64}`),
 		Entropy:     4,
-		Keywords:    []string{"dt0c01"},
+		Keywords:    []string{"dt0c01."},
 	}
 
 	// validate
