@@ -79,7 +79,7 @@ func GenericCredential() *config.Rule {
 
 						// Token
 						`|(?:csrf)[_.-]?token` +
-						`|(?:io\.jsonwebtoken[ \t]?:[ \t]?[\w-]+)` + // Maven library coordinats. (e.g., https://mvnrepository.com/artifact/io.jsonwebtoken/jjwt)
+						`|(?:io\.jsonwebtoken[ \t]?:[ \t]?[\w-]+)` + // Maven library coordinates. (e.g., https://mvnrepository.com/artifact/io.jsonwebtoken/jjwt)
 
 						// General
 						`|(?:api|credentials|token)[_.-]?(?:endpoint|ur[il])` +
