@@ -53,6 +53,7 @@ func TestWriteCSV(t *testing.T) {
 		t.Run(test.testReportName, func(t *testing.T) {
 			tmpfile, err := os.Create(filepath.Join(t.TempDir(), test.testReportName+".csv"))
 			require.NoError(t, err)
+			defer tmpfile.Close()
 
 			err = reporter.Write(tmpfile, test.findings)
 			require.NoError(t, err)
@@ -67,7 +68,10 @@ func TestWriteCSV(t *testing.T) {
 
 			want, err := os.ReadFile(test.expected)
 			require.NoError(t, err)
-			assert.Equal(t, string(want), string(got))
+
+			wantStr := lineEndingReplacer.Replace(string(want))
+			gotStr := lineEndingReplacer.Replace(string(got))
+			assert.Equal(t, wantStr, gotStr)
 		})
 	}
 }
